==> snappydata-store-core-1.5.3-sources.jar: com/pivotal/gemfirexd/internal/osgi/EmbeddedActivator.java <==
/*

   Derby - Class com.pivotal.gemfirexd.internal.osgi.EmbeddedActivator

   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */

/*
 * Changes for GemFireXD distributed data platform (some marked by "GemStone changes")
 *
 * Portions Copyright (c) 2010-2015 Pivotal Software, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License. See accompanying
 * LICENSE file.
 */

package com.pivotal.gemfirexd.internal.osgi;

import java.sql.DriverManager;
import java.sql.SQLException;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

public final class EmbeddedActivator implements BundleActivator {

	public void start(BundleContext context) {
		new com.pivotal.gemfirexd.jdbc.EmbeddedDriver();
	}

	public void stop(BundleContext context) {
		try {
// GemStone changes BEGIN
			DriverManager.getConnection("jdbc:gemfirexd:;shutdown=true");
			/* (original code)
			DriverManager.getConnection("jdbc:derby:;shutdown=true");
			*/
// GemStone changes END
		} catch (SQLException sqle) {
		}
	}
}

==> snappydata-store-core-1.6.1-sources.jar: com/pivotal/gemfirexd/internal/osgi/EmbeddedActivator.java <==
/*

   Derby - Class com.pivotal.gemfirexd.internal.osgi.EmbeddedActivator

   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */

/*
 * Changes for GemFireXD distributed data platform (some marked by "GemStone changes")
 *
 * Portions Copyright (c) 2010-2015 Pivotal Software, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License. See accompanying
 * LICENSE file.
 */

package com.pivotal.gemfirexd.internal.osgi;

import java.sql.DriverManager;
import java.sql.SQLException;

import io.snappydata.jdbc.EmbeddedDriver;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

public final class EmbeddedActivator implements BundleActivator {

	public void start(BundleContext context) {
		new EmbeddedDriver();
	}

	public void stop(BundleContext context) {
		try {
// GemStone changes BEGIN
			DriverManager.getConnection("jdbc:gemfirexd:;shutdown=true");
			/* (original code)
			DriverManager.getConnection("jdbc:derby:;shutdown=true");
			*/
// GemStone changes END
		} catch (SQLException sqle) {
		}
	}
}
